@@ -1,12 +1,8 @@
 import math
 
 
-def binary_search(array, target, is_ascending=True, is_left_most=True):
-    """ is_left_most is used when the array has duplicate entries """
-    if not array:
-        return None
-    begin, end = 0, len(array) - 1
-    while begin != end:
+def _binary_search(array, begin: int, end: int, target, is_ascending=True, is_left_most=True):
+    while begin < end:
         mid = begin + (end - begin) / 2
         mid = math.floor(mid) if is_left_most else math.ceil(mid)
         if (is_ascending and target < array[mid]) or (not is_ascending and target > array[mid]):
@@ -21,5 +17,8 @@ def binary_search(array, target, is_ascending=True, is_left_most=True):
     return begin if array[begin] == target else None
 
 
-def find_rotates(array, is_ascending=True):
-    pass
\ No newline at end of file
+def binary_search(array, target, is_ascending=True, is_left_most=True):
+    """ is_left_most is used when the array has duplicate entries """
+    if not array:
+        return None
+    return _binary_search(array, 0, len(array) - 1, target, is_ascending, is_left_most)
